@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load("Basic::Types::XS", $VERSION);
@@ -24,47 +24,129 @@ Basic::Types::XS - The great new Basic::Types::XS!
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
 =head1 SYNOPSIS
 
-	use Basic::Types::XS qw/Str/;
+	package Test;
 
-	Str->("abc");
+	use Moo;
+	use Basic::Types::XS qw/Str Num Int ArrayRef HashRef/;
 
-	Str->({ a => 1 }); # dies
+	has string => (
+		is       => 'ro',
+		isa      => Str,
+		required => 1,
+	);
+
+	has num => (
+		is       => 'ro',
+		isa      => Num,
+	);
+
+	has int => (
+		is       => 'rw',
+		isa      => Int,
+	);
+
+	has array => (
+		is       => 'ro',
+		isa      => ArrayRef,
+		default  => sub { return [] },
+	);
+
+	has hash => (
+		is       => 'ro',
+		isa      => HashRef,
+		default  => sub { return {} },
+	);
+
+	1;
 
 
 =head1 EXPORT
 
 =head2 Any
 
+Absolutely any value passes this type constraint (even undef).
+
+	Any->("abc");
+
 =head2 Defined
 
+Only undef fails this type constraint.
+
+	Defined->("abc");
+
 =head2 Bool
 
+Values that are reasonable booleans. Accepts 1, 0, "", undef, \1, \0, \"", \undef
+
+	Bool->(1);
+
 =head2 Str
 
+Values that are valid strings, this includes numbers.
+
+	Str->("abc");
+
 =head2 Num
 
+Values that are valid numbers, this incldues floats/doubles.
+
+	Num->(123.456);
+
 =head2 Int
 
+Values that are valide integers.
+
+	Int->(123);
+
 =head2 Ref
 
+Values that contain any reference
+
+	Ref->({ ... });
+
 =head2 ScalarRef
 
+Values that contain a scalar reference.
+
+	ScalarRef->(\"abc");
+
 =head2 ArrayRef
 
+Values that contain array references.
+
+	ArrayRef->([qw/a b c/]);
+
 =head2 HashRef
 
+Values that contain hash references
+
+	HashRef->({ a => 1, b => 2, c => 3 });
+
 =head2 CodeRef
 
+Values that contain code references
+
+	CodeRef->(sub { return 'abc' });
+
 =head2 RegexpRef
 
+Value that contain regexp references
+
+	RegexpRef->(qr/abc/);
+
 =head2 GlobRef
 
+Value that contain glob references
+
+	my $open, '>', 'abc.txt';
+	GlobRef->($open);
+
 =cut
 
 =head1 METHODS
